AdjustHelperService class
Constructors
- AdjustHelperService({required AdjustHelperConfig config, Client? httpClient})
Properties
- adjustAdid → String?
-
no setter
- config → AdjustHelperConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cacheCompatible(
) → Future< void> -
clearCache(
) → Future< void> -
initAdjust(
) → Future< void> -
loadImage(
) → Future< Uint8List?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performCheck(
) → Future< AdjustHelperCheckOutcome> -
toString(
) → String -
A string representation of this object.
inherited
-
waitForAdjustAttribution(
) → Future< Map< String, dynamic> ?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited